@@ -1,5 +1,5 @@
 /*
- *   $Id: defaults.h,v 1.9 2004/10/26 05:30:34 psavola Exp $
+ *   $Id: defaults.h,v 1.12 2005/07/05 08:10:28 psavola Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -69,7 +69,7 @@
 #define MAX_INITIAL_RTR_ADVERT_INTERVAL	16
 #define MAX_INITIAL_RTR_ADVERTISEMENTS	3
 #define MAX_FINAL_RTR_ADVERTISEMENTS	3
-#define MIN_DELAY_BETWEEN_RAS		3
+#define MIN_DELAY_BETWEEN_RAS		3.0
 #define MIN_DELAY_BETWEEN_RAS_MIPv6     (30.0/1000.0)
 #define MAX_RA_DELAY_TIME		(1000.0/2.0) /* milliseconds */
 
@@ -128,10 +128,10 @@
 #define ND_OPT_HOME_AGENT_INFO          8
 #endif
 
-/* draft-ietf-ipv6-router-selection-02.txt */
-/* XXX: not formally assigned, this will be changed! */
-#ifndef ND_OPT_ROUTE_INFORMATION
-#define  ND_OPT_ROUTE_INFORMATION	9	
+/* de-facto codepoint used by many implementations was '9',
+   the official IANA assignment will be '24' */
+#undef ND_OPT_ROUTE_INFORMATION
+#define  ND_OPT_ROUTE_INFORMATION	24
 
 /* XXX: some libc's like KAME already had nd_opt_route_info! */
 struct nd_opt_route_info_local     /* route information */
@@ -146,9 +146,7 @@ struct nd_opt_route_info_local     /* route information */
 
 /* the reserved field is 8 bits and we're interested of the middle two: 000xx000 */
 #define ND_OPT_RI_PRF_SHIFT	3
-#define ND_OPT_RI_PRF_MASK	(3 << ND_OPT_RI_PRF_SHIFT)
-
-#endif
+#define ND_OPT_RI_PRF_MASK	(3 << ND_OPT_RI_PRF_SHIFT) /* 00011000 = 0x18 */
 
 /* Flags */
 
@@ -166,8 +164,6 @@ struct nd_opt_route_info_local     /* route information */
 
 /* Other */
 
-#define AdvertisementInterval(iface)	((iface)->MaxRtrAdvInterval))
-
 #define MIN_MinRtrAdvInterval_MIPv6	(3.0/100.0)
 #define MIN_MaxRtrAdvInterval_MIPv6	(7.0/100.0)
 #define RTR_SOLICITATION_INTERVAL_MIPv6	1 /* Recommended value by MIPv6 */
