@@ -1,5 +1,5 @@
 /*
- *   $Id: interface.c,v 1.7 2004/10/26 05:30:34 psavola Exp $
+ *   $Id: interface.c,v 1.10 2005/03/29 15:15:20 psavola Exp $
  *
  *   Authors:
  *    Lars Fenneberg		<lf@elemental.net>	 
@@ -79,6 +79,7 @@ check_iface(struct Interface *iface)
 		iface->AdvIntervalOpt)
 	{
 		MIPv6 = 1;
+		flog(LOG_INFO, "using Mobile IPv6 extensions");
 	}
 
 	prefix = iface->AdvPrefixList;	
@@ -91,121 +92,61 @@ check_iface(struct Interface *iface)
 		prefix = prefix->next;
 	}
 
-	if (MIPv6)
-	{
-		flog(LOG_INFO, "using Mobile IPv6 extensions");
-	}
-
 	if (iface->MinRtrAdvInterval == -1)
 		iface->MinRtrAdvInterval = DFLT_MinRtrAdvInterval(iface);
 
-	/* Mobile IPv6 ext */
-	if (MIPv6)
-	{
-		if ((iface->MinRtrAdvInterval < MIN_MinRtrAdvInterval_MIPv6) || 
+	if ((iface->MinRtrAdvInterval < (MIPv6 ? MIN_MinRtrAdvInterval_MIPv6 : MIN_MinRtrAdvInterval)) || 
 		    (iface->MinRtrAdvInterval > MAX_MinRtrAdvInterval(iface)))
-		{
-			flog(LOG_ERR, 
-				"MinRtrAdvInterval for %s must be between %.2f and %.2f",
-				iface->Name, MIN_MinRtrAdvInterval_MIPv6,
-				MAX2(MIN_MinRtrAdvInterval_MIPv6, MIN_MinRtrAdvInterval_MIPv6));
-			res = -1;
-		}
-	}
-	else
 	{
-		if ((iface->MinRtrAdvInterval < MIN_MinRtrAdvInterval) || 
-		    (iface->MinRtrAdvInterval > MAX_MinRtrAdvInterval(iface)))
-		{
-			flog(LOG_ERR, 
-				"MinRtrAdvInterval for %s must be between %d and %d",
-				iface->Name, (int)MIN_MinRtrAdvInterval,
-				(int)MAX_MinRtrAdvInterval(iface));
-			res = -1;
-		}
+		flog(LOG_ERR, 
+			"MinRtrAdvInterval for %s (%.2f) must be at least %.2f but no more than 3/4 of MaxRtrAdvInterval (%.2f)",
+			iface->Name, iface->MinRtrAdvInterval,
+			MIPv6 ? MIN_MinRtrAdvInterval_MIPv6 : (int)MIN_MinRtrAdvInterval,
+			MAX_MinRtrAdvInterval(iface));
+		res = -1;
 	}
 
-	/* Mobile IPv6 ext */
-	if (MIPv6)
-	{
-		if ((iface->MaxRtrAdvInterval < MIN_MaxRtrAdvInterval_MIPv6) 
+	if ((iface->MaxRtrAdvInterval < (MIPv6 ? MIN_MaxRtrAdvInterval_MIPv6 : MIN_MaxRtrAdvInterval)) 
 			|| (iface->MaxRtrAdvInterval > MAX_MaxRtrAdvInterval))
-		{
-			flog(LOG_ERR, 
-				"MaxRtrAdvInterval for %s must be between %.2f and %d",
-				iface->Name, MIN_MaxRtrAdvInterval_MIPv6,
-				MAX_MaxRtrAdvInterval);
-			res = -1;
-		}
-	}
-	else
 	{
-		if ((iface->MaxRtrAdvInterval < MIN_MaxRtrAdvInterval) 
-			|| (iface->MaxRtrAdvInterval > MAX_MaxRtrAdvInterval))
-		{
-			flog(LOG_ERR, 
-				"MaxRtrAdvInterval must be between %d and %d for %s",
-				MIN_MaxRtrAdvInterval, MAX_MaxRtrAdvInterval, iface->Name);
-			res = -1;
-		}
+		flog(LOG_ERR, 
+			"MaxRtrAdvInterval for %s (%.2f) must be between %.2f and %d",
+			iface->Name, iface->MaxRtrAdvInterval,
+			MIPv6 ? MIN_MaxRtrAdvInterval_MIPv6 : (int)MIN_MaxRtrAdvInterval,
+			MAX_MaxRtrAdvInterval);
+		res = -1;
 	}
 
-	/* Mobile IPv6 ext */
-	if (MIPv6)
+	if (iface->MinDelayBetweenRAs < (MIPv6 ? MIN_DELAY_BETWEEN_RAS_MIPv6 : MIN_DELAY_BETWEEN_RAS)) 
 	{
-		if (iface->MinDelayBetweenRAs < MIN_DELAY_BETWEEN_RAS_MIPv6) 
-		{
-			flog(LOG_ERR, 
-				"MinDelayBetweenRAs for %s must be greater than %.2f",
-				iface->Name, MIN_DELAY_BETWEEN_RAS_MIPv6);
-			res = -1;
-		}
-	}
-	else
-	{
-		if (iface->MinDelayBetweenRAs < MIN_DELAY_BETWEEN_RAS)
-		{
-			flog(LOG_ERR, 
-				"MinDelayBetweenRAs for %s must be greater than %.2f",
-				iface->Name, (double) MIN_DELAY_BETWEEN_RAS);
-			res = -1;
-		}
+		flog(LOG_ERR, 
+			"MinDelayBetweenRAs for %s (%.2f) must be at least %.2f",
+			iface->Name, iface->MinDelayBetweenRAs,
+			MIPv6 ? MIN_DELAY_BETWEEN_RAS_MIPv6 : MIN_DELAY_BETWEEN_RAS);
+		res = -1;
 	}
 
-	if (iface->if_maxmtu != -1)
+	if ((iface->AdvLinkMTU != 0) &&
+	   ((iface->AdvLinkMTU < MIN_AdvLinkMTU) || 
+	   (iface->if_maxmtu != -1 && (iface->AdvLinkMTU > iface->if_maxmtu))))
 	{
-		if ((iface->AdvLinkMTU != 0) &&
-		   ((iface->AdvLinkMTU < MIN_AdvLinkMTU) || 
-		   (iface->AdvLinkMTU > iface->if_maxmtu)))
-		{
-			flog(LOG_ERR,  "AdvLinkMTU must be zero or between %d and %d for %s",
-			MIN_AdvLinkMTU, iface->if_maxmtu, iface->Name);
-			res = -1;
-		}
-	}
-	else
-	{
-		if ((iface->AdvLinkMTU != 0) 
-			&& (iface->AdvLinkMTU < MIN_AdvLinkMTU))
-		{
-			flog(LOG_ERR,  "AdvLinkMTU must be zero or greater than %d for %s",
-			MIN_AdvLinkMTU, iface->Name);
-			res = -1;
-		}
+		flog(LOG_ERR,  "AdvLinkMTU for %s (%u) must be zero or between %u and %u",
+		iface->Name, iface->AdvLinkMTU, MIN_AdvLinkMTU, iface->if_maxmtu);
+		res = -1;
 	}
 
 	if (iface->AdvReachableTime >  MAX_AdvReachableTime)
 	{
 		flog(LOG_ERR, 
-			"AdvReachableTime must be less than %d for %s",
-			MAX_AdvReachableTime, iface->Name);
+			"AdvReachableTime for %s (%u) must not be greater than %u",
+			iface->Name, iface->AdvReachableTime, MAX_AdvReachableTime);
 		res = -1;
 	}
 
 	if (iface->AdvCurHopLimit > MAX_AdvCurHopLimit)
 	{
-		flog(LOG_ERR, "AdvCurHopLimit must not be greater than %d for %s",
-			MAX_AdvCurHopLimit, iface->Name);
+		flog(LOG_ERR, "AdvCurHopLimit for %s (%u) must not be greater than %u",
+			iface->Name, iface->AdvCurHopLimit, MAX_AdvCurHopLimit);
 		res = -1;
 	}
 	
@@ -225,8 +166,8 @@ check_iface(struct Interface *iface)
 	    (iface->AdvDefaultLifetime < MIN_AdvDefaultLifetime(iface))))
 	{
 		flog(LOG_ERR, 
-			"AdvDefaultLifetime for %s must be zero or between %.0f and %.0f",
-			iface->Name, MIN_AdvDefaultLifetime(iface),
+			"AdvDefaultLifetime for %s (%u) must be zero or between %u and %u",
+			iface->Name, iface->AdvDefaultLifetime, MIN_AdvDefaultLifetime(iface),
 			MAX_AdvDefaultLifetime);
 		res = -1;
 	}
@@ -238,22 +179,19 @@ check_iface(struct Interface *iface)
 			(iface->HomeAgentLifetime < MIN_HomeAgentLifetime))
 		{
 			flog(LOG_ERR, 
-				"HomeAgentLifetime must be between %d and %d for %s",
-				MIN_HomeAgentLifetime, MAX_HomeAgentLifetime,
-				iface->Name);
+				"HomeAgentLifetime for %s (%u) must be between %u and %u",
+				iface->Name, iface->HomeAgentLifetime,
+				MIN_HomeAgentLifetime, MAX_HomeAgentLifetime);
 			res = -1;
 		}
 	}
 
 	/* Mobile IPv6 ext */
-	if (MIPv6)
+	if (iface->AdvHomeAgentInfo && !(iface->AdvHomeAgentFlag))
 	{
-		if (iface->AdvHomeAgentInfo && !(iface->AdvHomeAgentFlag))
-		{
-			flog(LOG_ERR, 
-				"AdvHomeAgentFlag must be set with HomeAgentInfo");
-			res = -1;
-		}
+		flog(LOG_ERR, 
+			"AdvHomeAgentFlag for %s must be set with HomeAgentInfo", iface->Name);
+		res = -1;
 	}
 
 	/* XXX: need this? prefix = iface->AdvPrefixList; */
@@ -262,15 +200,15 @@ check_iface(struct Interface *iface)
 	{
 		if (prefix->PrefixLen > MAX_PrefixLen)
 		{
-			flog(LOG_ERR, "invalid prefix length for %s", iface->Name);
+			flog(LOG_ERR, "invalid prefix length (%u) for %s", prefix->PrefixLen, iface->Name);
 			res = -1;
 		}
 
 		if (prefix->AdvPreferredLifetime > prefix->AdvValidLifetime)
 		{
-			flog(LOG_ERR, "AdvValidLifetime must be "
-				"greater than AdvPreferredLifetime for %s", 
-				iface->Name);
+			flog(LOG_ERR, "AdvValidLifetime for %s (%u) must be "
+				"greater than AdvPreferredLifetime for", 
+				iface->Name, prefix->AdvValidLifetime);
 			res = -1;
 		}
 
@@ -284,7 +222,7 @@ check_iface(struct Interface *iface)
 	{
 		if (route->PrefixLen > MAX_PrefixLen)
 		{
-			flog(LOG_ERR, "invalid route prefix length for %s", iface->Name);
+			flog(LOG_ERR, "invalid route prefix length (%u) for %s", route->PrefixLen, iface->Name);
 			res = -1;
 		}
 
